@@ -12,9 +12,16 @@ package org.torproject.descriptor;
 @SuppressWarnings("deprecation")
 public class DescriptorParseException
     extends org.torproject.descriptor.impl.DescriptorParseException {
+
   private static final long serialVersionUID = 100L;
+
   public DescriptorParseException(String message) {
     super(message);
   }
+
+  public DescriptorParseException(String message, Exception ex) {
+    super(message, ex);
+  }
+
 }
 
